LabTestsService

Struct LabTestsService 

pub struct LabTestsService { /* private fields */ }

Implementations

Source

impl LabTestsService

pub fn new(client: MetrcClient, rate_limiter: Arc<MetrcRateLimiter>) -> Self

pub async fn create_lab_tests_record( &self, license_number: Option<String>, body: Option<Vec<CreateRecordRequestItem>>, ) -> Result<Option<WriteResponse>, Box<dyn Error + Send + Sync>>

POST CreateRecord Submits Lab Test results for one or more packages. NOTE: This endpoint allows only PDF files, and uploaded files can be no more than 5 MB in size. The Label element in the request is a Package Label. Permissions Required:

  • View Packages
  • Manage Packages Inventory Parameters:
  • body (Option<&Value>): Request body
  • license_number (Option): Filter by licenseNumber
pub async fn get_lab_tests_batches( &self, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<PaginatedResponse<Batch>>, Box<dyn Error + Send + Sync>>

GET GetBatches Retrieves a list of Lab Test batches. Parameters:

  • page_number (Option): Filter by pageNumber
  • page_size (Option): Filter by pageSize
pub async fn get_lab_tests_lab_test_document_by_id( &self, id: &str, license_number: Option<String>, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>

GET GetLabTestDocumentById Retrieves a specific Lab Test result document by its Id for a given Facility. Permissions Required:

  • View Packages
  • Manage Packages Inventory Parameters:
  • id (str): Path parameter id
  • license_number (Option): Filter by licenseNumber
pub async fn get_lab_tests_types( &self, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<PaginatedResponse<LabTestsType>>, Box<dyn Error + Send + Sync>>

GET GetLabTestsTypes Returns a list of Lab Test types. Parameters:

  • page_number (Option): Filter by pageNumber
  • page_size (Option): Filter by pageSize
pub async fn get_lab_tests_results( &self, license_number: Option<String>, package_id: Option<String>, page_number: Option<String>, page_size: Option<String>, body: Option<&Value>, ) -> Result<Option<PaginatedResponse<Result>>, Box<dyn Error + Send + Sync>>

GET GetResults Retrieves Lab Test results for a specified Package. Permissions Required:

  • View Packages
  • Manage Packages Inventory Parameters:
  • license_number (Option): Filter by licenseNumber
  • package_id (Option): Filter by packageId
  • page_number (Option): Filter by pageNumber
  • page_size (Option): Filter by pageSize
pub async fn get_lab_tests_states( &self, body: Option<&Value>, ) -> Result<Option<Value>, Box<dyn Error + Send + Sync>>

GET GetStates Returns a list of all lab testing states. Parameters:

pub async fn update_lab_tests_lab_test_document( &self, license_number: Option<String>, body: Option<Vec<UpdateLabTestDocumentRequestItem>>, ) -> Result<Option<WriteResponse>, Box<dyn Error + Send + Sync>>

PUT UpdateLabTestDocument Updates one or more documents for previously submitted lab tests. Permissions Required:

  • View Packages
  • Manage Packages Inventory Parameters:
  • body (Option<&Value>): Request body
  • license_number (Option): Filter by licenseNumber
pub async fn update_lab_tests_results_release( &self, license_number: Option<String>, body: Option<Vec<UpdateResultsReleaseRequestItem>>, ) -> Result<Option<WriteResponse>, Box<dyn Error + Send + Sync>>

PUT UpdateResultsRelease Releases Lab Test results for one or more packages. Permissions Required:

  • View Packages
  • Manage Packages Inventory Parameters:
  • body (Option<&Value>): Request body
  • license_number (Option): Filter by licenseNumber